#!/usr/bin/env python3

import re
import sys
import time
import urllib.request

# the only important line from "pmset -g pslog" as a regex;
# it reports percentage, state and an estimated duration
# e.g. "('91', 'discharging', '7:19 remaining')"
RE_report = re.compile(".*\s+(\d+)%;\s+(.+);\s+(.+)\s+present:")

def log(*stuff):
    print(time.ctime(), *stuff)

domoticzserver="jk-pi:8080"
widgetID=15

# url for updating a (virtual) string device; value will be supplied later on...
url = "http://%s/json.htm?type=command&param=udevice&idx=%d&nvalue=0&svalue=%%s" % (
        domoticzserver, widgetID)

def domoticzrequest (url):
    request = urllib.request.Request(url)
    response = urllib.request.urlopen(request)
    return response.read()

# this script should be run as e.g. "pmset -g pslog | ReportBattery.py";
# so output from "pmset" will be received on stdin
for line in sys.stdin:
    line = line.strip()

    if not re.search("InternalBattery", line):
        # (expected) noise from "pmset"
        continue

    m = RE_report.match(line)
    if not m:
        # (unexpected) noise from "pmset"
        log("ERR", line)
    else:
        # extract values and send them to our domoticz server
        log("OK", m.groups())
        percentage, state, remaining = m.groups()
        info = "%s%% / %s / %s" % (percentage, state, remaining)
        domoticzrequest(url % urllib.parse.quote_plus(info))
